@@ -615,7 +615,7 @@ class VariableClTargetFs(Variable):
     def get(self):
         if self.value != 'auto':
             return self.value
-        return 'ntfs'
+        return 'vfat'
 
     def choice(self):
         return ['vfat', 'btrfs', 'ntfs', 'ext4',
